@@ -35,7 +35,7 @@ class MdB(object):
     def __init__(self, OVN_dic = None, base_name = 'OVN',tmp_base_name = 'OVN_tmp', 
                  user_name = 'OVN_user', user_passwd = 'getenv', 
                  host = 'localhost', unix_socket = '/var/mysql/mysql.sock', port = 3306,
-                 connect = True):
+                 connect = True, master_table='tab'):
         """
         This is the package to deal with MySQL OVN database. 
         You must have MySQL or PyMySQL library installed. The latest is easier to get working, as it comes with its own
@@ -72,6 +72,8 @@ class MdB(object):
                 unix_socket = OVN_dic['unix_socket']
             if 'port' in OVN_dic:
                 port = OVN_dic['port']
+            if 'master_table' in OVN_dic:
+                master_table = OVN_dic['master_table']
         self.base_name = base_name
         self.tmp_base_name = tmp_base_name
         self.user_name = user_name
@@ -84,6 +86,7 @@ class MdB(object):
         self.port = port
         self.host = host
         self.unix_socket = unix_socket
+        self.table = master_table
         self._dB = None
         self._cursor = None
         self._cursor_tuple = None
@@ -114,7 +117,7 @@ class MdB(object):
             
     def use_dB(self, base_name = None):
         if not self.connected:
-            pc.log_.error('Not connected to the database')
+            pc.log_.error('Not connected to the serevr')
             return None        
         if base_name is None:
             self._dB.select_db(self.base_name)
@@ -123,7 +126,7 @@ class MdB(object):
             
     def use_dB_tmp(self, tmp_base_name = None):
         if not self.connected:
-            pc.log_.error('Not connected to the database')
+            pc.log_.error('Not connected to the server')
             return None
         if tmp_base_name is None:
             self._dB.select_db(self.tmp_base_name)
@@ -148,8 +151,8 @@ class MdB(object):
         else:
             self.log_.warn('Not connected', calling = self.calling)
 
-    def exec_dB(self, command, format_ = 'dict'):
-        if format_ not in ('dict', 'tuple', 'numpy', 'dict2', 'pandas'):
+    def exec_dB(self, command, format_ = 'dict', return_descr=False):
+        if format_ not in ('dict', 'tuple', 'numpy', 'dict2', 'pandas', 'rec'):
             self.log_.error('format"{0}" not recognized'.format(format_), calling = self.calling)
         if not self.connected:
             self.log_.error('Not connected to a database', calling = self.calling)
@@ -161,7 +164,7 @@ class MdB(object):
                 return res, len(res)
             else:
                 pc.log_.error('pandas is not available, use another format', calling=self.calling)
-        if format_[0:4] == 'dict':
+        if format_[0:4] == 'dict' or format_ == 'rec':
             cursor = self._cursor
         else:
             cursor = self._cursor_tuple
@@ -173,9 +176,14 @@ class MdB(object):
             res = cursor.fetchall()
         except:
             self.log_.error('Error on reading result of {0}'.format(command), calling = self.calling)
-        return res, N
+        if format_ == 'rec':
+            res = np.rec.fromrecords([e.values() for e in res], names = res[0].keys())
+        if return_descr:
+            return res, N, cursor.description
+        else:
+            return res, N
             
-    def select_dB(self, select_ = '*', from_ = 'OVN.tab1', where_ = None, order_ = None, group_ = None, 
+    def select_dB(self, select_ = '*', from_ = None, where_ = None, order_ = None, group_ = None, 
                   limit_ = 1, format_ = 'dict', dtype_ = None):
         """
         Usage:
@@ -185,6 +193,8 @@ class MdB(object):
                         format_='numpy')
             loglog(dd['L_26']/dd['L_1'], dd['L_21']/dd['L_1'], 'r+')            
         """
+        if from_ is None:
+            from_ = self.table
         if (type(select_) == type(())) or (type(select_) == type([])):
             this_select = ''
             for w in select_:
@@ -232,14 +242,18 @@ class MdB(object):
             res = res2
         return res, N 
     
-    def count_dB(self, from_ = 'OVN.tab1', where_ = None):
+    def count_dB(self, from_ = None, where_ = None):
+        if from_ is None:
+            from_ = self.table
         req = 'SELECT count(*) FROM {0}'.format(from_)
         if where_ is not None:
             req += ' WHERE ({0})'.format(where_)
         res, N = self.exec_dB(req)
         return res[0]['count(*)']
     
-    def get_fields(self, from_ = 'OVN.tab1'):
+    def get_fields(self, from_ = None):
+        if from_ is None:
+            from_ = self.table
         froms = from_.split(',')
         if len(froms) == 1:
             res, N = self.exec_dB('SHOW COLUMNS FROM {0}'.format(from_))
@@ -252,7 +266,9 @@ class MdB(object):
                 fields.extend(self.get_fields(from_ = this_from))
             return fields
     
-    def get_cols(self, select_ = '*', from_ = 'OVN.tab1'):
+    def get_cols(self, select_ = '*', from_ = None):
+        if from_ is None:
+            from_ = self.table
         froms = from_.split(',')
         
         if len(froms) == 1:
@@ -272,7 +288,9 @@ class MdB(object):
                 res += self.get_cols(select_ = select_, from_ = this_from)
             return res
             
-    def get_dtype(self, select_ = '*', from_ = 'OVN.tab1'):
+    def get_dtype(self, select_ = '*', from_ = None):
+        if from_ is None:
+            from_ = self.table
         dtype_list = []
         if select_ == '*':        
             cols = self.get_cols(select_ = select_, from_ = from_)
@@ -307,7 +325,7 @@ class MdB_subproc(object):
     def __init__(self, OVN_dic = None, base_name = 'OVN',tmp_base_name = 'OVN_tmp', 
                  user_name = 'OVN_user', user_passwd = 'getenv', 
                  host = 'localhost', unix_socket = '/var/mysql/mysql.sock', port = 3306,
-                 connect = True):
+                 connect = True, master_table=None):
         
         self.log_ = self.__class__.MdBlog_
         self.calling = 'MdB'
@@ -326,6 +344,8 @@ class MdB_subproc(object):
                 unix_socket = OVN_dic['unix_socket']
             if 'port' in OVN_dic:
                 port = OVN_dic['port']
+            if 'master_table' in OVN_dic:
+                master_table = OVN_dic['master_table']
         self.base_name = base_name
         self.tmp_base_name = tmp_base_name
         self.user_name = user_name
@@ -338,6 +358,7 @@ class MdB_subproc(object):
         self.port = port
         self.host = host
         self.unix_socket = unix_socket
+        self.table = master_table
         self._dB = None
         self._cursor = None
         self._cursor_tuple = None
@@ -350,8 +371,6 @@ class MdB_subproc(object):
         pass
     
     def exec_dB(self, command, outfile=None):
-        if format_ not in ('dict', 'tuple', 'numpy', 'dict2'):
-            self.log_.error('format"{0}" not recognized'.format(format_), calling = self.calling)
         if not self.connected:
             self.log_.error('Not connected to a database', calling = self.calling)
             return None
@@ -378,7 +397,7 @@ class MdB_subproc(object):
             N = None
         return out, N
 
-    def select_dB(self, select_ = '*', from_ = 'OVN.tab1', where_ = None, order_ = None, group_ = None, limit_ = 1,
+    def select_dB(self, select_ = '*', from_ = None, where_ = None, order_ = None, group_ = None, limit_ = 1,
                   format_ = 'dict2', dtype_ = None, outfile=None):
         """
         Usage:
@@ -388,6 +407,8 @@ class MdB_subproc(object):
                         format_='numpy')
             loglog(dd['L_26']/dd['L_1'], dd['L_21']/dd['L_1'], 'r+')            
         """
+        if from_ is None:
+            from_ = self.table
         req = 'SELECT {0} FROM {1} '.format(select_, from_)
         if where_ is not None:
             req += 'WHERE ({0}) '.format(where_)
